==> kubernetes-model-1.0.28-sources.jar: io/fabric8/openshift/api/model/ProjectStatusBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;

public class ProjectStatusBuilder extends ProjectStatusFluent<ProjectStatusBuilder> implements VisitableBuilder<ProjectStatus,ProjectStatusBuilder>{

     ProjectStatusFluent<?> fluent;
public ProjectStatusBuilder(){
    this(new ProjectStatus());
}
public ProjectStatusBuilder( ProjectStatusFluent<?> fluent ){
    this(fluent, new ProjectStatus());
}
public ProjectStatusBuilder( ProjectStatusFluent<?> fluent , ProjectStatus instance ){
    this.fluent = fluent; fluent.withPhase(instance.getPhase()); 
}
public ProjectStatusBuilder( ProjectStatus instance ){
    this.fluent = this; this.withPhase(instance.getPhase()); 
}

public EditableProjectStatus build(){
    EditableProjectStatus buildable = new EditableProjectStatus(fluent.getPhase());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
ProjectStatusBuilder that = (ProjectStatusBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.48-sources.jar: io/fabric8/openshift/api/model/ProjectStatusBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class ProjectStatusBuilder extends ProjectStatusFluentImpl<ProjectStatusBuilder> implements VisitableBuilder<ProjectStatus,ProjectStatusBuilder>{

     ProjectStatusFluent<?> fluent;
public ProjectStatusBuilder(){
    this(new ProjectStatus());
}
public ProjectStatusBuilder( ProjectStatusFluent<?> fluent ){
    this(fluent, new ProjectStatus());
}
public ProjectStatusBuilder( ProjectStatusFluent<?> fluent , ProjectStatus instance ){
    this.fluent = fluent; fluent.withPhase(instance.getPhase()); 
}
public ProjectStatusBuilder( ProjectStatus instance ){
    this.fluent = this; this.withPhase(instance.getPhase()); 
}

public EditableProjectStatus build(){
    EditableProjectStatus buildable = new EditableProjectStatus(fluent.getPhase());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
ProjectStatusBuilder that = (ProjectStatusBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
